@@ -7,11 +7,11 @@
 __all__ = ['IISShortnameTool']
 
 
-import unittest
-import doctest
+#import unittest
+#import doctest
 
 from webget import WebgetTool
-from xnet.net.ipv4 import IPRangeIterator
+#from xnet.net.ipv4 import IPRangeIterator
 
 
 class IISShortnameTool(WebgetTool):
